.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _presentation:

canary: Accelerating Application Testing Across Platforms
=========================================================

A Flexible, Extensible, and Scalable Framework for Scientific Applications

**Authors**: Tim Fuller, Stuart Baxley, Mario LoPrinzi, Matt Mosby, Scot Swan

**Affiliation**: Sandia National Laboratories

.. toctree::
    :maxdepth: 1

    Introduction <intro>
    Key features <features>
    Technical architectures <technical>
    Use cases <use-cases>
    Performance <performance>
    Extensibility <extensibility>
    Future work and roadmap <future>
    Conclusion <conclusion>
